@@ -262,94 +262,112 @@ MultiviewValues Multiview( DataFrame< double > & dataFrameIn,
                            bool        verbose         = false,
                            unsigned    nThreads        = 4 );
 
-DataFrame< double > EmbedDimension( std::string pathIn        = "./data/",
-                                    std::string dataFile      = "",
-                                    std::string pathOut       = "./",
-                                    std::string predictFile   = "",
-                                    std::string lib           = "",
-                                    std::string pred          = "",
-                                    int         maxE          = 10,
-                                    int         Tp            = 1,
-                                    int         tau           = -1,
-                                    std::string colNames      = "",
-                                    std::string targetName    = "",
-                                    bool        embedded      = false,
-                                    bool        verbose       = true,
-                                    unsigned    nThreads      = 4 );
+DataFrame< double > EmbedDimension( std::string pathIn          = "./data/",
+                                    std::string dataFile        = "",
+                                    std::string pathOut         = "./",
+                                    std::string predictFile     = "",
+                                    std::string lib             = "",
+                                    std::string pred            = "",
+                                    int         maxE            = 10,
+                                    int         Tp              = 1,
+                                    int         tau             = -1,
+                                    int         exclusionRadius = 0,
+                                    std::string colNames        = "",
+                                    std::string targetName      = "",
+                                    bool        embedded        = false,
+                                    bool        verbose         = true,
+                                    std::vector<bool> validLib  =
+                                                      std::vector<bool>(),
+                                    unsigned    nThreads        = 4 );
 
 DataFrame< double > EmbedDimension( DataFrame< double > & dataFrameIn,
-                                    std::string pathOut       = "./",
-                                    std::string predictFile   = "",
-                                    std::string lib           = "",
-                                    std::string pred          = "",
-                                    int         maxE          = 10,
-                                    int         Tp            = 1,
-                                    int         tau           = -1,
-                                    std::string colNames      = "",
-                                    std::string targetName    = "",
-                                    bool        embedded      = false,
-                                    bool        verbose       = true,
-                                    unsigned    nThreads      = 4 );
+                                    std::string pathOut         = "./",
+                                    std::string predictFile     = "",
+                                    std::string lib             = "",
+                                    std::string pred            = "",
+                                    int         maxE            = 10,
+                                    int         Tp              = 1,
+                                    int         tau             = -1,
+                                    int         exclusionRadius = 0,
+                                    std::string colNames        = "",
+                                    std::string targetName      = "",
+                                    bool        embedded        = false,
+                                    bool        verbose         = true,
+                                    std::vector<bool> validLib  =
+                                                      std::vector<bool>(),
+                                    unsigned    nThreads        = 4 );
 
-DataFrame< double > PredictInterval( std::string pathIn        = "./data/",
-                                     std::string dataFile      = "",
-                                     std::string pathOut       = "./",
-                                     std::string predictFile   = "",
-                                     std::string lib           = "",
-                                     std::string pred          = "",
-                                     int         maxTp         = 10,
-                                     int         E             = 0,
-                                     int         tau           = -1,
-                                     std::string colNames      = "",
-                                     std::string targetName    = "",
-                                     bool        embedded      = false,
-                                     bool        verbose       = true,
-                                     unsigned    nThreads      = 4 );
+DataFrame< double > PredictInterval( std::string pathIn          = "./data/",
+                                     std::string dataFile        = "",
+                                     std::string pathOut         = "./",
+                                     std::string predictFile     = "",
+                                     std::string lib             = "",
+                                     std::string pred            = "",
+                                     int         maxTp           = 10,
+                                     int         E               = 0,
+                                     int         tau             = -1,
+                                     int         exclusionRadius = 0,
+                                     std::string colNames        = "",
+                                     std::string targetName      = "",
+                                     bool        embedded        = false,
+                                     bool        verbose         = true,
+                                     std::vector<bool> validLib  =
+                                                       std::vector<bool>(),
+                                     unsigned    nThreads        = 4 );
 
 DataFrame< double > PredictInterval( DataFrame< double > & dataFrameIn,
-                                     std::string pathOut       = "./",
-                                     std::string predictFile   = "",
-                                     std::string lib           = "",
-                                     std::string pred          = "",
-                                     int         maxTp         = 10,
-                                     int         E             = 0,
-                                     int         tau           = -1,
-                                     std::string colNames      = "",
-                                     std::string targetName    = "",
-                                     bool        embedded      = false,
-                                     bool        verbose       = true,
-                                     unsigned    nThreads      = 4 );
+                                     std::string pathOut         = "./",
+                                     std::string predictFile     = "",
+                                     std::string lib             = "",
+                                     std::string pred            = "",
+                                     int         maxTp           = 10,
+                                     int         E               = 0,
+                                     int         tau             = -1,
+                                     int         exclusionRadius = 0,
+                                     std::string colNames        = "",
+                                     std::string targetName      = "",
+                                     bool        embedded        = false,
+                                     bool        verbose         = true,
+                                     std::vector<bool> validLib  =
+                                                       std::vector<bool>(),
+                                     unsigned    nThreads        = 4 );
 
-DataFrame< double > PredictNonlinear( std::string pathIn        = "./data/",
-                                      std::string dataFile      = "",
-                                      std::string pathOut       = "./",
-                                      std::string predictFile   = "",
-                                      std::string lib           = "",
-                                      std::string pred          = "",
-                                      std::string theta         = "",
-                                      int         E             = 0,
-                                      int         Tp            = 1,
-                                      int         knn           = 0,
-                                      int         tau           = -1,
-                                      std::string colNames      = "",
-                                      std::string targetName    = "",
-                                      bool        embedded      = false,
-                                      bool        verbose       = true,
-                                      unsigned    nThreads      = 4 );
+DataFrame< double > PredictNonlinear( std::string pathIn          = "./data/",
+                                      std::string dataFile        = "",
+                                      std::string pathOut         = "./",
+                                      std::string predictFile     = "",
+                                      std::string lib             = "",
+                                      std::string pred            = "",
+                                      std::string theta           = "",
+                                      int         E               = 0,
+                                      int         Tp              = 1,
+                                      int         knn             = 0,
+                                      int         tau             = -1,
+                                      int         exclusionRadius = 0,
+                                      std::string colNames        = "",
+                                      std::string targetName      = "",
+                                      bool        embedded        = false,
+                                      bool        verbose         = true,
+                                      std::vector<bool> validLib  =
+                                                        std::vector<bool>(),
+                                      unsigned    nThreads        = 4 );
 
 DataFrame< double > PredictNonlinear( DataFrame< double > & dataFrameIn,
-                                      std::string pathOut       = "./",
-                                      std::string predictFile   = "",
-                                      std::string lib           = "",
-                                      std::string pred          = "",
-                                      std::string theta         = "",
-                                      int         E             = 0,
-                                      int         Tp            = 1,
-                                      int         knn           = 0,
-                                      int         tau           = -1,
-                                      std::string colNames      = "",
-                                      std::string targetName    = "",
-                                      bool        embedded      = false,
-                                      bool        verbose       = true,
-                                      unsigned    nThreads      = 4 );
+                                      std::string pathOut         = "./",
+                                      std::string predictFile     = "",
+                                      std::string lib             = "",
+                                      std::string pred            = "",
+                                      std::string theta           = "",
+                                      int         E               = 0,
+                                      int         Tp              = 1,
+                                      int         knn             = 0,
+                                      int         tau             = -1,
+                                      int         exclusionRadius = 0,
+                                      std::string colNames        = "",
+                                      std::string targetName      = "",
+                                      bool        embedded        = false,
+                                      bool        verbose         = true,
+                                      std::vector<bool> validLib  =
+                                                        std::vector<bool>(),
+                                      unsigned    nThreads        = 4 );
 #endif
