@@ -95,7 +95,7 @@ Parameters::Parameters(
 
     // Set validated flag and instantiate Version
     validated        ( false ),
-    version          ( 1, 12, 0, "2022-05-07" )
+    version          ( 1, 12, 2, "2022-05-25" )
 {
     // Constructor code
     if ( method != Method::None ) {
@@ -127,6 +127,11 @@ void Parameters::Validate() {
                             "tau must be non-zero.\n" );
         throw std::runtime_error( errMsg );
     }
+    if ( tau > 0 ) {
+        std::string errMsg( "WARNING: Parameters::Validate(): "
+                            "Positive tau is experimental.\n" );
+        std::cout << errMsg;
+    }
 
     //--------------------------------------------------------------
     // Convert multi argument parameters from string to vectors
